@@ -3,6 +3,8 @@
 import asyncio
 from datetime import datetime
 import json
+import logging
+import time
 from typing import Dict, List as TypeList,TypeVar, Generic, Union
 from sqlalchemy.orm import declarative_base,load_only
 
@@ -14,7 +16,8 @@ from .friendly_exception import FriendlyException
 from sqlalchemy.ext.asyncio import AsyncSession
 from sqlalchemy import select,update,delete,insert, func,text,event
 from sqlalchemy.engine import Engine
-
+from kxy.framework.context import last_log_time
+from kxy.framework.__logger import kxyLogger
 from .base_config import BaseConfig
 
 T = TypeVar("T", bound=declarative_base)
@@ -24,12 +27,14 @@ filter_dict = {
     '_dep_field': dep_id,
     '_user_field': user_id,
 }
+# 监听 SQL 执行事件
+@event.listens_for(Engine, "before_cursor_execute")
+def receive_before_cursor_execute(conn, cursor, statement, parameters, context, executemany):
+    last_log_time.set(time.time())
 @event.listens_for(Engine, "after_cursor_execute")
 def receive_after_cursor_execute(conn, cursor, statement, parameters, context, executemany):
-    BaseConfig.AppLogger.refresh_time()
-@event.listens_for(Engine, "after_cursor_execute")
-def receive_after_cursor_execute(conn, cursor, statement, parameters, context, executemany):
-    BaseConfig.AppLogger.info(f'{statement} , parameters: {parameters}','sql')
+    kxyLogger.info(statement%parameters,extra={'Category':'sql'})
+
 
 class BaseDal(Generic[T]):
     _id_field = 'Id'
