@@ -1,6 +1,7 @@
 import httpx
 from kxy.framework.context import trace_id, session_id, user_id, access_token
 from kxy.framework.base_config import BaseConfig
+from kxy.framework.__logger import kxyLogger
 class HttpClient:
     @staticmethod
     def get_default_headers():
@@ -20,14 +21,13 @@ class HttpClient:
     async def request(cls, method, url, **kwargs):
         headers = kwargs.pop('headers', {})
         headers.update(cls.get_default_headers())
-        BaseConfig.AppLogger.refresh_time()
         try:
             async with httpx.AsyncClient() as client:
                 result = await client.request(method, url, headers=headers, **kwargs)
-                BaseConfig.AppLogger.info(f'{method} {url} success {result.status_code}','http')
+                kxyLogger.info(f'{method} {url} success {result.status_code}',extra={'Category':'http'})
                 return result
         except Exception as ex:
-            BaseConfig.AppLogger.error(f'{method} {url} error:{ex}','http')
+            kxyLogger.error(f'{method} {url} error:{ex}',extra={'Category':'http'})
             raise ex
     
     @classmethod
