@@ -9,11 +9,12 @@ project_root = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
 if project_root not in sys.path:
     sys.path.insert(0, project_root)
     
-from kxy.framework.slogger import create_logger
+from kxy.framework.slogger import init_logger
+from kxy.framework.kxy_logger import KxyLogger
 
-create_logger(logging.DEBUG,'kxy.mall.api','production',filename='log/app',file_type='log',backupCount=5,maxBytes=10000,mutiple_process=False,cleanup_mode='zip',disk_max=1)
-
-logger = logging.getLogger(__name__)
+init_logger(logging.DEBUG,'kxy.mall.api','production',filename='log/app',file_type='log',backupCount=5,maxBytes=10000,mutiple_process=False,cleanup_mode='zip',disk_max=1)
+logger = KxyLogger.getLogger('sdfsfsdf')
+# logger = logging.getLogger(__name__)
 
 
 logger.info('hello world1',extra={"logCategory":'http'})
